=======
History
=======

0.2.1-dev
---------

TODO
^^^^

* ``Domain.users`` should returns ``User`` objects
* update submission status after reload a just finalized submission


0.2.0 (2018-10-23)
------------------

Features
^^^^^^^^

* Fetch submission by name
* changed library name to ``pyUSIrest``
* published to pypi
* Finalize submission with *PUT*

0.1.0 (2018-10-17)
------------------

Features
^^^^^^^^

* submit into biosample with python methods
